@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * bfspell.c - aspell spell checker
  *
- * Copyright (C) 2002-2004 Olivier Sessink
+ * Copyright (C) 2002-2005 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,8 +15,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
+
 /* #define DEBUG */
 
 #include "config.h"
@@ -213,7 +214,9 @@ void spell_start(Tbfspell *bfspell) {
 	 * default language should come from config file, runtime from GUI,
 	 * should first set the default one 
 	 */
-	aspell_config_replace(bfspell->spell_config, "lang", main_v->props.spell_default_lang);
+	if (main_v->props.spell_default_lang) {
+		aspell_config_replace(bfspell->spell_config, "lang", main_v->props.spell_default_lang);
+	}
 	DEBUG_MSG("spell_start, default lang=%s\n",main_v->props.spell_default_lang);
 	/*
 	 * it is unclear from the manual if aspell supports utf-8 in the
