@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef __HTML_H_
@@ -23,6 +23,11 @@
 
 #include "html_diag.h" /* Ttagpopup */
 
+typedef enum {
+        linkdialog_mode_default,
+        linkdialog_mode_css
+} Tlinkdialog_mode;
+
 void insert_char_cb(Tbfwin* bfwin,guint callback_action, GtkWidget *widget);
 void general_html_menu_cb(Tbfwin* bfwin,guint callback_action, GtkWidget *widget);
 
@@ -49,7 +54,7 @@ void frameset_dialog(Tbfwin *bfwin, Ttagpopup *data);
 void frame_dialog(Tbfwin *bfwin, Ttagpopup *data);
 void embed_dialog(Tbfwin *bfwin, Ttagpopup *data);
 void script_dialog(Tbfwin *bfwin, Ttagpopup *data);
-void linkdialog_dialog(Tbfwin *bfwin, Ttagpopup *data);
+void linkdialog_dialog(Tbfwin *bfwin, Ttagpopup *data, Tlinkdialog_mode mode);
 
 #ifndef HAVE_ATLEAST_GTK_2_4
 void quickstart_dialog(Tbfwin *bfwin, Ttagpopup *data);
