@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef __HTML_DIAG_H_
@@ -35,12 +35,12 @@ typedef struct {
 extern Trecent_attribs recent_attribs;
 
 typedef struct {
-	GtkWidget *src;
+	GtkWidget *name;
+	GtkWidget *val;
 	GtkWidget *dest;
 	gint type;
 } Tphpvarins; /* this struct contains a src and dest widget for PHP variable generation*/
 
-
 typedef struct {
 	gchar *item;
 	gchar *value;
@@ -74,10 +74,13 @@ typedef struct {
 	GtkWidget *check[8];
 	GtkWidget *clist[4];
 	GtkWidget *text[1];
+	GtkWidget *attrwidget[20]; /* all attribute widgets should go in here */
 	Treplacerange range;
 	GtkTextMark *mark_ins;
 	GtkTextMark *mark_sel;
 	Tphpvarins php_var_ins;
+	GtkWidget *phpbutton;
+	gboolean tobedestroyed; /* this will be set to TRUE on destroy */
 	Tdocument *doc;
 	Tbfwin *bfwin;
 } Thtml_diag;
@@ -98,10 +101,12 @@ void parse_existence_for_dialog(gchar * valuestring, GtkWidget * checkbox);
 void parse_integer_for_dialog(gchar * valuestring, GtkWidget * spin, GtkWidget * entry, GtkWidget * checkbox);
 
 gchar *insert_string_if_entry(GtkWidget * entry, gchar * itemname, gchar * string2add2, gchar *defaultvalue);
-gchar *insert_integer_if_spin(GtkWidget * spin, gchar * itemname, gchar * string2add2, GtkWidget * percentage);
+gchar *insert_integer_if_spin(GtkWidget * spin, gchar * itemname, gchar * string2add2, gboolean ispercentage, gint dontinsertonvalue);
 gchar *insert_attr_if_checkbox(GtkWidget * checkbox, gchar * itemname, gchar *string2add2);
 gchar *format_entry_into_string(GtkEntry * entry, gchar * formatstring);
 GList *add_entry_to_stringlist(GList *which_list, GtkWidget *entry);
 
+GtkWidget *generic_table_inside_notebookframe(GtkWidget *notebook, const gchar *title, gint rows, gint cols);
+void generic_class_id_style_section(Thtml_diag *dg, gint firstattrwidget, GtkWidget *table, gint firstrowintable, gchar **tagvalues, gint firsttagvalue);
 
 #endif /* __HTML_DIAG_H_ */
