@@ -1,5 +1,5 @@
 /* Bluefish HTML Editor
- * quickstart.c --> quickstart dialog
+ * quickstart.c - quickstart dialog
  *
  * Copyright (C) 2005 James Hayward and Olivier Sessink
  *
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
  
 /*
@@ -99,6 +99,7 @@ static struct {
 	{ "XHTML 1.0 Strict", "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">"  },
 	{ "XHTML 1.0 Transitional", "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">" },
 	{ "XHTML 1.0 Frameset", "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Frameset//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd\">" },
+	{ "XHTML 1.1", "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">" },
 };
 
 static void
@@ -185,10 +186,10 @@ quickstart_load_metatags(GtkListStore *lstore)
 		"name=\"keywords\" content=\"\"",
 		"name=\"description\" content=\"\"",
 		"name=\"ROBOTS\" content=\"NOINDEX, NOFOLLOW\"",
-		"http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"",
-		"http-equiv=\"Content-Type\" content=\"application/xhtml+xml; charset=UTF-8\"",
-		"http-equiv=\"Content-Style-Type\" content=\"text/css\"",
-		"http-equiv=\"Expires\" content=\"\"",
+		"http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"",
+		"http-equiv=\"content-type\" content=\"application/xhtml+xml; charset=UTF-8\"",
+		"http-equiv=\"content-style-type\" content=\"text/css\"",
+		"http-equiv=\"expires\" content=\"0\"",
 		"http-equiv=\"refresh\" content=\"5; URL=http://\"",
 	};
 
@@ -301,7 +302,11 @@ quickstart_response_lcb(GtkDialog *dialog, gint response, TQuickStart *qstart)
 			
 		if (strstr(name, "XHTML")) {
 			xmlstr = g_strconcat ("<?xml version=\"1.0\" encoding=\"", main_v->props.newfile_default_encoding, "\"?>\n", NULL);
-			tmpstr = g_strdup_printf ("%shttp://www.w3.org/1999/xhtml%sen%sen\">\n%s\n", cap("<HTML XMLNS=\""), cap("\" XML:LANG=\""), cap("\" LANG=\""), cap("<HEAD>"));
+			if (strstr(name, "1.1")) { 
+			    tmpstr = g_strdup_printf ("%shttp://www.w3.org/1999/xhtml%sen\">\n%s\n", cap("<HTML XMLNS=\""), cap("\" XML:LANG=\""), cap("<HEAD>"));
+			} else {			    
+			    tmpstr = g_strdup_printf ("%shttp://www.w3.org/1999/xhtml%sen%sen\">\n%s\n", cap("<HTML XMLNS=\""), cap("\" XML:LANG=\""), cap("\" LANG=\""), cap("<HEAD>"));
+			}
 			endstr = g_strdup ("/>\n");
 		} else {
 			xmlstr = g_strdup ("");
@@ -348,18 +353,21 @@ quickstart_response_lcb(GtkDialog *dialog, gint response, TQuickStart *qstart)
 			styletitle = gtk_editable_get_chars (GTK_EDITABLE (qstart->styletitle), 0, -1);
 			
 			if (strcmp(name, "Linked") == 0) {
-				stylestr = g_string_append (stylestr, "<link rel=stylesheet type=\"text/css\" ");
+			    tmpstr2 = g_strdup_printf ("<link href=\"%s\" rel=\"stylesheet\" type=\"text/css\"", stylehref);
+			    stylestr = g_string_append (stylestr, tmpstr2);
+			    g_free (tmpstr2);
+			    
 				if (strlen(stylemedia) > 0) {
 					if (strlen(styletitle) > 0) {
-						tmpstr2 = g_strdup_printf ("media=\"%s\" href=\"%s\" title=\"%s\">\n", stylemedia, stylehref, styletitle);
+						tmpstr2 = g_strdup_printf (" media=\"%s\" title=\"%s\">\n", stylemedia, styletitle);
 					} else {
-						tmpstr2 = g_strdup_printf ("media=\"%s\" href=\"%s\">\n", stylemedia, stylehref);
+						tmpstr2 = g_strdup_printf (" media=\"%s\">\n", stylemedia);
 					}
 				} else {
 					if (strlen(styletitle) > 0) {
-						tmpstr2 = g_strdup_printf ("href=\"%s\" title=\"%s\">\n", stylehref, styletitle);
+						tmpstr2 = g_strdup_printf (" title=\"%s\">\n", styletitle);
 					} else {
-						tmpstr2 = g_strdup_printf ("href=\"%s\">\n", stylehref);
+					    tmpstr2 = g_strdup (">\n");
 					}
 				}
 			} else {
@@ -401,8 +409,8 @@ quickstart_response_lcb(GtkDialog *dialog, gint response, TQuickStart *qstart)
 		}
 		
 		finalstr = g_strconcat (xmlstr, dtdstr, tmpstr, titlestr, metastr->str, 
-										stylestr->str, stylearea, scriptsrc, scriptarea, 
-										cap("</HEAD>\n"), is_frameset_dtd ? cap("<FRAMESET>\n") : cap("<BODY>\n"), NULL);
+                                    stylestr->str, stylearea, scriptsrc, scriptarea, 
+                                    cap("</HEAD>\n"), is_frameset_dtd ? cap("<FRAMESET>\n") : cap("<BODY>\n"), NULL);
 		
 		g_free (xmlstr);
 		g_free (dtdstr);
@@ -421,8 +429,8 @@ quickstart_response_lcb(GtkDialog *dialog, gint response, TQuickStart *qstart)
 		}
 
 		doc_insert_two_strings(qstart->bfwin->current_document, 
-									  finalstr, 
-									  is_frameset_dtd ? cap("\n</FRAMESET>\n</HTML>") : cap("\n</BODY>\n</HTML>"));
+                                finalstr, 
+                                is_frameset_dtd ? cap("\n</FRAMESET>\n</HTML>") : cap("\n</BODY>\n</HTML>"));
 		g_free (finalstr);
 		
 		doc_set_filetype(qstart->bfwin->current_document, get_filetype_by_name("html"));
@@ -457,7 +465,7 @@ quickstart_meta_page_create(TQuickStart *qstart)
 	qstart->metaView = gtk_tree_view_new ();
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (qstart->metaView), FALSE);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (qstart->metaView));
-	g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (quickstart_meta_selection_changed), qstart);
+	
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	gtk_container_add (GTK_CONTAINER (scrolwin), qstart->metaView);
 	renderer = gtk_cell_renderer_text_new ();
@@ -480,6 +488,8 @@ quickstart_meta_page_create(TQuickStart *qstart)
 	gtk_widget_set_sensitive (qstart->removeButton, FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, FALSE, 0);
 	
+	g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (quickstart_meta_selection_changed), qstart);
+	
 	return hbox;
 }
 
@@ -685,7 +695,10 @@ quickstart_dialog_new(Tbfwin *bfwin)
 	gtk_tree_selection_select_iter (selection, &iter);
 	
 	qstart->openNewDoc = gtk_check_button_new_with_mnemonic (_("Open in _new document."));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (qstart->openNewDoc), TRUE);
+	if (doc_is_empty_non_modified_and_nameless(bfwin->current_document))
+	    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (qstart->openNewDoc), FALSE);
+	else
+	    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (qstart->openNewDoc), TRUE);	
 	alignment = gtk_alignment_new (0, 0.5, 0, 0);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 8, 4, 0);
 	gtk_container_add (GTK_CONTAINER (alignment), qstart->openNewDoc);
